{% extends "markettracker/base.html" %}
{% load i18n %}
{% block content %}
<h2>{% trans "Contract errors" %}</h2>
<table class="table table-striped">
  <thead>
    <tr>
      <th>{% trans "When" %}</th>
      <th>{% trans "Seeder" %}</th>
      <th>{% trans "Tracked" %}</th>
      <th>{% trans "Contract" %}</th>
      <th>{% trans "Error" %}</th>
      <th>{% trans "Message" %}</th>
    </tr>
  </thead>
  <tbody>
    {% for e in errors %}
    <tr>
      <td>{{ e.created_at|date:"Y-m-d H:i" }}</td>
      <td>{{ e.owner_name }}</td>
      <td>{{ e.tracked }}</td>
      <td>{{ e.contract_id }}</td>
      <td>{{ e.get_code_display }}</td>
      <td>{{ e.message }}</td>
    </tr>
    {% empty %}
    <tr><td colspan="6" class="text-center text-muted">{% trans "No errors." %}</td></tr>
    {% endfor %}
  </tbody>
</table>
{% endblock %}
